Crate win_sid

Crate win_sid 

Crate for parsing Windows security identifiers without depending on any Windows-only APIs. This crate is capable of parsing SIDs from their canonical string representation (e.g. S-1-5-21-1004336348-1177238915-682003330-512) as well as their canonical binary representation found within binary SDDLs, LDAP attributes, etc.

Modules

well_known
Module contains all well-known const SIDs as well as functions for generating well-known SIDs that are relative to another resource. For example, the Domain Admins group has the same relative identifier in every domain, but the sub authority is unique per domain.

Macros

sid
The sid macro will parse/validate a SID at compile time.

Structs

IdentifierAuthority
A type representing the first value after the SID version.
SecurityIdentifier
Core type representing Windows security identifiers (“SID“s). Type represents version one SIDs, which consist of a single 48 bit identifier authority, followed by up to 256 sub-authorities.

Enums

SecurityIdentifierError
Represents all errors that may be encountered during either binary or string parsing of a SID.